from django import forms
from .models import pieza, equipo, marca, ubicacion, rentrada, rsalida, area


class Formulariopieza(forms.ModelForm):
    class Meta:
        model = pieza
        fields = ('referencia', 'equipo', 'descripcion_etiqueta', 'descripcion_pieza', 'marca', 'estatus', 'ubicacion', 'cantidad')


class Formularioequipo(forms.ModelForm):
    class Meta:
        model = equipo
        fields = ('nombre',)


class Formulariomarca(forms.ModelForm):
    class Meta:
        model = marca
        fields = ('nombre',)


class Formularioarea(forms.ModelForm):
    class Meta:
        model = area
        fields = ('nombre','ib',)


class Formularioubicacion(forms.ModelForm):
    class Meta:
        model = ubicacion
        fields = ('nombre',)


class Formularioentrada(forms.ModelForm):
    class Meta:
        model = rentrada
        fields = ('n_pedido', 'referencia', 'cantidad')


class Formulariosalida(forms.ModelForm):
    class Meta:
        model = rsalida
        fields = ('referencia', 'cantidad')
